@@ -11,6 +11,8 @@ from metaphor.models.metadata_change_event import (
     PersonLogicalID,
 )
 
+from metaphor.common.event_util import EventUtil
+
 
 @dataclass
 class EntityId:
@@ -18,7 +20,7 @@ class EntityId:
     logicalId: Union[DatasetLogicalID, DashboardLogicalID, PersonLogicalID, GroupID]
 
     def __str__(self) -> str:
-        json = encode_canonical_json(self.logicalId.to_dict())
+        json = encode_canonical_json(EventUtil.clean_nones(self.logicalId.to_dict()))
         return f"{self.type.name}~{hashlib.md5(json).hexdigest().upper()}"
 
     def __hash__(self):
